@@ -2,7 +2,7 @@
 
 function bluer_objects_ls() {
     local options=$1
-    local where=$(bluer_ai_option_choice "$options" cloud,local local)
+    local where=$(bluer_ai_option_choice "$options" cloud,local)
     local objects=$(bluer_ai_option_int "$options" objects 0)
 
     if [[ "$objects" == 1 ]]; then
@@ -14,6 +14,11 @@ function bluer_objects_ls() {
         return
     fi
 
+    if [[ -z "$where" ]]; then
+        ls -1 "$@"
+        return
+    fi
+
     local object_name=$(bluer_ai_clarify_object $2 .)
 
     python3 -m bluer_objects.storage \
