@@ -1,6 +1,7 @@
 from bluer_ai.help.generic import help_functions as generic_help_functions
 
 from bluer_objects import ALIAS
+from bluer_objects.help.assets import help_functions as help_assets
 from bluer_objects.help.clone import help_clone
 from bluer_objects.help.create_test_asset import help_create_test_asset
 from bluer_objects.help.download import help_download
@@ -16,6 +17,7 @@ help_functions = generic_help_functions(plugin_name=ALIAS)
 
 help_functions.update(
     {
+        "assets": help_assets,
         "clone": help_clone,
         "create_test_asset": help_create_test_asset,
         "download": help_download,
