@@ -42,9 +42,23 @@ def help_ls(
         mono=mono,
     )
 
+    # ---
+
+    usage_3 = show_usage(
+        [
+            "@ls",
+            "[<path>]",
+        ],
+        "ls <path>.",
+        mono=mono,
+    )
+
+    # ---
+
     return "\n".join(
         [
             usage_1,
             usage_2,
+            usage_3,
         ]
     )
